(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    119491,       2110]
NotebookOptionsPosition[    118949,       2087]
NotebookOutlinePosition[    119322,       2103]
CellTagsIndexPosition[    119279,       2100]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Solution from http : // mathematica.stackexchange.com/questions/58596/pde - \
with - stefan - conditions - a - k - a - variable - boundary\
\>", "Text",
 CellChangeTimes->{{3.682763650046001*^9, 3.682763668316001*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", "1000"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Delta]\[Xi]", "=", 
    RowBox[{"1.", "/", "n"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ClearAll", "[", 
   RowBox[{"dv", ",", "t"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dv", "[", "v_List", "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "=", 
        RowBox[{"First", "@", "v"}]}], ",", 
       RowBox[{"u", "=", 
        RowBox[{"Rest", "@", "v"}]}]}], "}"}], ",", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"ds", "=", 
          RowBox[{
           RowBox[{"u", "[", 
            RowBox[{"[", 
             RowBox[{"-", "1"}], "]"}], "]"}], "/", 
           RowBox[{"(", 
            RowBox[{"s", " ", "\[Delta]\[Xi]"}], ")"}]}]}], ",", 
         RowBox[{"\[Xi]", "=", 
          RowBox[{
           RowBox[{"N", "@", 
            RowBox[{"Range", "[", 
             RowBox[{"n", "-", "1"}], "]"}]}], "/", "n"}]}], ",", 
         RowBox[{"d1", "=", 
          RowBox[{
           RowBox[{"ListCorrelate", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "0.5"}], ",", "0", ",", "0.5"}], "}"}], "/", 
              "\[Delta]\[Xi]"}], ",", "#"}], "]"}], "&"}]}], ",", 
         RowBox[{"d2", "=", 
          RowBox[{
           RowBox[{"ListCorrelate", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", 
                RowBox[{"-", "2"}], ",", "1"}], "}"}], "/", 
              RowBox[{"\[Delta]\[Xi]", "^", "2"}]}], ",", "#"}], "]"}], 
           "&"}]}]}], "}"}], ",", 
       RowBox[{"Prepend", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"d2", "[", "#", "]"}], "/", 
             RowBox[{"s", "^", "2"}]}], "+", 
            RowBox[{"\[Xi]", " ", "ds", " ", 
             RowBox[{
              RowBox[{"d1", "[", "#", "]"}], "/", "s"}]}]}], "&"}], "@", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"u", "[", 
               RowBox[{"[", "1", "]"}], "]"}], "+", 
              RowBox[{"s", " ", "\[Delta]\[Xi]"}]}], "}"}], ",", "u", ",", 
            RowBox[{"{", "0.", "}"}]}], "]"}]}], ",", "ds"}], "]"}]}], 
      "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s0", "=", "0.001"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"v0", "=", 
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"0.", ",", 
       RowBox[{"n", "-", "1"}]}], "]"}], ",", "s0"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"sol", "=", 
    RowBox[{
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"v", "'"}], "[", "t", "]"}], "\[Equal]", 
          RowBox[{"dv", "[", 
           RowBox[{"v", "[", "t", "]"}], "]"}]}], ",", 
         RowBox[{
          RowBox[{"v", "[", "0", "]"}], "\[Equal]", "v0"}]}], "}"}], ",", "v",
        ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "Needs", "@", 
   "\"\<DifferentialEquations`InterpolatingFunctionAnatomy`\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"values", "=", 
   RowBox[{"InterpolatingFunctionValuesOnGrid", "@", "sol"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"valu", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Transpose", "@", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"#", "[", 
           RowBox[{"[", "2", "]"}], "]"}], "+", 
          RowBox[{"\[Delta]\[Xi]", " ", 
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"Rest", "@", "#"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", " ", 
          RowBox[{"#", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "}"}]}], "]"}]}], "&"}], "@", 
    RowBox[{"Transpose", "@", 
     RowBox[{"InterpolatingFunctionValuesOnGrid", "@", "sol"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"vals", "=", 
   RowBox[{
    RowBox[{"InterpolatingFunctionValuesOnGrid", "[", "sol", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"Flatten", "@", 
    RowBox[{"InterpolatingFunctionGrid", "@", "sol"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"\[Xi]", "=", 
   RowBox[{
    RowBox[{"Range", "[", 
     RowBox[{"0.", ",", "n"}], "]"}], "/", "n"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"s", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"vals", ",", "t"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"u\[Xi]", "=", 
   RowBox[{"ListInterpolation", "[", 
    RowBox[{"valu", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "\[Xi]"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"u", "=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"#2", "<", 
       RowBox[{"s", "[", "#", "]"}]}], ",", 
      RowBox[{"u\[Xi]", "[", 
       RowBox[{"#", ",", 
        RowBox[{"#2", "/", 
         RowBox[{"s", "[", "#", "]"}]}]}], "]"}], ",", "0."}], "]"}], "&"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.672933094441*^9, 3.6729331069379997`*^9}, 
   3.672933147797*^9, 3.672933534598*^9, {3.672933702519*^9, 
   3.67293370287*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"DensityPlot", "[", 
     RowBox[{
      RowBox[{"u", "[", 
       RowBox[{"t", ",", "x"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "5"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<t\>\"", ",", "\"\<x\>\""}], "}"}]}]}], "]"}], ",", 
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"s", "[", "t", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"Red", ",", "Dashed"}], "}"}]}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6729331228929996`*^9, 3.672933160799*^9}, {
  3.672934923917*^9, 3.6729349301400003`*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJx1WM1u3DYYXG9lpU623mgtC3WjOFaiPod0dY55hAA5un2PHPsMeYZtn2Dv
ufhiXwwEAgIYKFykRIMYTeKlZoiZXS8MECOSHzmc74d08/r3V2+mk8nk7c5k
ctf678+zi+XZxdApDsSnf7Tf/3Z67c+Jf10PmPU6viCOv9LmV8S/3cHlkdmr
iS/vus+emf2GuF1/eG7rtYax7nkHvooDMfhqf04Mvjq+IAZfnV8Rg6/aq4nB
V+03xOCr67WGk67b20CsfAfjOxjfwfgOxncwvoPxHYzvYHwH4zsY38H4Duan
N8brhnyBwVf7c2Lw1fEFMfjq/IoYfNVeTQy+ar8hBl9drzWc4nS7rsF4Q99g
+gbTN5i+wfQNpm8wfYPpG0zfYPoG0zeYvikPRbu3nfrRbafr3pKv9ufE4Kvj
C2Lw1fkVMfiqvZoYfNV+Qwy+ul5rOOXd7XEazI9Tq/6Mc5jZuIJY/RnzK2L1
Z9iridWfYb8hVn/Geq1h/DKL68z8ILN5GfkCaz3KyBcYfHV+Raz1KOu1HmW9
1qOMfIG1HmG91nCqo9vzbuhcR+1PrcZvTr56LqXNq4g1fvNe4zfvNX5z8gXW
+M3J1+8JcZ09qwt75Ausfrdn+9wjXx1fEIOvzq+IwVft1cTgq/YbYvDV9VrD
6V60vY6GzuPSddQ8NbM4LszPS5tf2TkdmZ2aWPPVjHyBNV/NyNfvfdHO3Or6
nHyBNW/Mzc/mtq85+QKDr86viMFX7dXE4Kv2G2Lw1fVaw+meu/1eFOzesLMR
l66jji8sb5U2vzK/PzJ7tZ3bM7PbEGt+LshXMe7ZC7uXLcgXWPP+wvLEwvxq
YftYkK/Or4jBV+3VxOCr9hti8NX1WsP4pXut4mD3wFRHPe96nLqu3mo9Kq0e
lVaPSqtHJfnqOT63dVpifaes7B10xXtztHM9trinfGJdjvv83Gke/dppXE1N
p93+5dr+k7F9NO7reGz373nXnHfbv6+6tZnTFz0w+Dq/OO6AegNjvmOcl+K0
Hz9fzNd1lzzneK7vbf+pH9/X496Bj81/d9Cj37Gfi+8P4/V8lrau20vvHviH
vkuv7f2V+jVv3HI87MGfNJ9c27vthv6G8bAH/9N4TP1+z8B42IO/6n0j9ev9
fs7xei+YWv36unGv0Tw0tbq0a/lwanUH+zzkeNiL/vYjdfJ+zUvHjDfEX/y+
z/zi/crrhONhL35/bPnI+1Fvr0ZdLu2dPpifXLON5/iReuq8QP+BbnHcPxvv
COig46bj+f3X6b0wvR+hp57z/xv3Gq1vU57DetjFjtWZzOr07jgOdT3j+WNd
YOwzfv+ZeqFeAEe7v4ztQ+rh90HsM9p7OrY/9ZIPGM8r6qfx73quTNeV1ZX3
xHGVD8TQW3VNeA3P/iaG3hejTo4j/3+JoTfO3XE8vy/E0FvrVMJx3ITnDr0R
F47jej8QQ2/UDcfRbt7/tbbzhHoCx/YRMfSLdo43cGz3e9V1afqdWxxeWn36
cI+u6f9UWheWFr9Xlp+HTu8RHxm/sKNxc8P4hd76Dvu08c5EHKnec+YDfTfg
nrNPvRG/yAfAiH/Er+p9aPn8kPEf1y2pN/o9n+u+D0Z7DxjPOv7Y8sNT+gvy
t/rtieaDxQn9Bf2e39Vvx3yyeMz9ax0tuV+1N+d6mP8NhR0yWQ==
    "], {
     {GrayLevel[0.8], EdgeForm[None], 
      GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxNmHecVsUVhu9VBASliFJXEBVE+iJdcF2UIiCwdFGE3RUEhF1BRECqiIBG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        "]]]}, {}, {}, {}, {}},
    VertexColors->CompressedData["
1:eJztWWdUFOuWJSgqRhBBFAHJRhDEi4mNYEBAQQQkXlFAjIASJYoYCRKVqICK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     "]], {{}, {}, 
    {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
     Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVj3s01HkAxcdjiEHmZ0liDD/bRhFJotb3Ugyhl22VIoTVriLZJCEpLXm0
bFlFZMtJLTrUIkuzTSWPkaKU7SXlTYNGNGOs/eOe+8/n3PO5RoHhW4PlGQyG
51z+7/z4QCWroNMOJ5al3vcL3Ewu+gzbe3P3kifyCwrowgjywjM1ksuNIaYV
PZQvJ45E83ZoMLkppHdvq5n1bCpxuYddnw1zyWL+kJJJRy4pPb4ySWRYQi5K
RdtZrBLSHVCmM2JYQx4pFT5I31BNYrf85D9k2Egku3ok8l4NRGX6QmOYRRd5
bhl2wLb5GTlwNyFtOLKHtEmT6uJM3xKLy9mPb5YNkEPjtg+MU9+TDxtD9d+s
FhHXC50eEuUBkqOXbHDJf4II3EaqmpVGiF1kdblCyyThuQhi686JiKDzwubw
b76QvMM2N8+njROrNJmDrtsMOWvaPuO75RPh9dq/sfRmIMdjw2iy+STpM//L
+dOwHDqWik0LXn0msdIU67+PKMAi7tpU5ZFposzu3/udGRPPjXzKl1tKCFPI
5LHqlMBobTm2/I6USFpLw7IOzMNwFqfx5xAZ+eBdtpDDUYX89rdpfjOzxPGX
/fselrLw+/6nVV3VDJyVVaus262O9U+jBukEOezUF3i8nNBA54mjrxVt5KHG
XzpsvE0TL4vXlnRMyiPYpki8Yxkbd4y6HzMqFBAdf3grV8yG1nDta5mvIk4O
Zre3tlKoUYx2u6fNhIfZ/Ktq57UQYSIQfqxnIr10Fd8j4Cvwb3jWFgUqocnr
D2mUnTbux5dmjrKVwReGpy1T0IFT0uuYQ5XKqPgxES2vdLCvUudqkP88cNzJ
6v03F6AuYmuZ7jwVrJvdlVRwVBeykBWD9UUqCHp2Z7x620KMRu02P++qCofE
47cCuHrItXZm/dOtiqzwsVq1Pj0U89wjAg6x8O7Yld6C+kV4kRrTqaSjhqHg
mqC7p/QhrsoxSSxRg2gfpSwMMED/mi1j7Tx1lLk1S0PMOXDK2uTi1KWO3lDL
VQpiDh7pDy45HaoBvetd2aeEhji5QMsrQW4+kvwji4TuXDQVVNvLMubjs3Rh
unsNFwnx07IELU0sqc3JbTIxghlrqDjaVxM2e+5vYqcYYdR00rDvkib4edq6
LWIjbJRvKz4+NMfztVM37jRGpnNGYPlyNjyZwwZP6o3hZXHjITOSDdG/7wWN
ZjT6867ZRdWwEZ6XrpWSSWNNRDYrX8JGi5zJxw2/0hi11g0WSNkw++F2k1o2
jbgj3rcGZth4b9WXeOYcDVUFVftVDArbGyDKyach/dqvo1WRgtP4REvxdRrm
HbWeMnUKOq4+yfcaaLQ81975PZfCwVJRQHIjDSqPyog1otBGnfrWtZmGZcxI
VaExhdOvKj81t9IQTjiKBk0oMA6q72l/SqNc4+REvCmFwXw+eddD46MkzPnK
Cgo8Be9Flz/QaH7S1ttoTeFy6MhkcN+cT4ZJwuhKCrut9coGBuf+mRX+ZmtL
oePhQf2xMRoumspejWsoWFmoTlVM0Oi2UflzZC2FjOzC9igxjczFilK2AwU3
P2Hq1BQN5sv+Yz6gUCzYE3L7y9xeV8eteEcKiqZfHI9KaQTr1HcXOVEIyDhj
4CCjYVd6RbFhHYX6icXTs7M0ImrTOEPrKfwHxJwpSA==
      "]]}}},
  AspectRatio->1,
  AxesLabel->{None, None},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{{
     FormBox["\"x\"", TraditionalForm], None}, {
     FormBox["\"t\"", TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic, 
    "ScalingFunctions" -> None},
  PlotRange->{{0, 10}, {0, 5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.6729331242460003`*^9, {3.672933155594*^9, 3.672933162008*^9}, 
   3.672933549803*^9, 3.672933750314*^9, 3.6729345051470003`*^9, {
   3.672934924332*^9, 3.672934930532*^9}, 3.6827633221800013`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"des", "=", 
  RowBox[{"Plot3D", "[", 
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"t", ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.672933273237*^9, 3.672933277362*^9}, {
  3.682763365194001*^9, 3.682763365941001*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJydvXlYTd37+H+aZSxCZdbJmIxlbh9DdGRMxkjImAaiQjKmJCSUsYEiihCn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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmgn4V0P7xs+cmfNtQaFdZKlUKtoUIaSylRaUoqQIJVHZkn3Jmn0Xsi/Z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          "]], Polygon3DBox[CompressedData["
1:eJwtmgn4F9MbxWfm3vlRqaRFlLSQ0GIpWVpspaKSiqIVhUL2PWuUIiTZs4US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          "]], Polygon3DBox[CompressedData["
1:eJwt13mgVtMexvH3vOc9b1IijVRoJKHcZkVIUhFXhChEGW51QpMMSZFoHpFK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          "]], Polygon3DBox[{{1164, 711, 857, 1421, 994, 995}}]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
         "Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0ssrZ2EYB/B33H4YtwVRJreScl/IamxoVqxs1FDu15nY8hdQlCRETZJ+
mL3fX8ByNoPBuFuxlKxmLHxOWTzn833qvOd5z3tO+cBU5+SHEMKCKhCinO/y
zPnkEPL4Sb8ul8ol8p5cLz+khFCmb5Ef5Qq5Q05JDaFL7pZjco98b82E/pUz
zHT/HIu4xirusJkJfuEhr5lmfYM61lfzo+pNCuFEXyz3yX/kfp5ygGcc5DmH
+JfDHFEX8igvOcYrjvOaE7zhN97yO+/Ybt/pZjVG76KvYVY02/6O9J08YBv3
2cQ4K7nKQs4yg9P873n/1Lh8y6/8zXYe8DMTrOMOS/jL2hfWmpsbnRkz1E+V
o99lNuPR3rgdnRW3mMnN6H7+YDo3ou+qYvIa07hCnyws07iwROPDIh1FaNU8
vf8rb9E+PwA=
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{907, 1249, 1250, 1226, 621, 906, 1429, 1121, 908, 1430, 1122,
        909, 1431, 1123, 910, 1432, 1124, 911, 1433, 1125, 912, 1434, 1331, 
       1530, 913, 1435, 1126, 914, 1436, 1127, 915, 1437, 1128, 916, 1438, 
       1129, 917, 1439, 1130, 918, 1440, 1131, 919, 1622, 1227, 1132, 1228}], 
      Line3DBox[{921, 285, 1229, 1332, 1618, 920, 636, 922, 1441, 1133, 923, 
       1442, 1134, 924, 1443, 1135, 925, 1444, 1136, 926, 1445, 1333, 1531, 
       927, 1334, 1532, 928, 1446, 1137, 929, 1447, 1138, 930, 1448, 1139, 
       931, 1449, 1140, 932, 1450, 1141, 933, 1451, 1142, 934}], 
      Line3DBox[{936, 1254, 1213, 1230, 1335, 1619, 935, 1323, 1324, 1336, 
       1644, 937, 1337, 1533, 938, 1452, 1143, 939, 1453, 1144, 940, 1454, 
       1145, 941, 1455, 1338, 1534, 942, 1339, 1535, 943, 1340, 1536, 944, 
       1456, 1146, 945, 1457, 1147, 946, 1458, 1148, 947, 1459, 1149, 948, 
       1460, 1150, 949}], 
      Line3DBox[{963, 1156, 1467, 962, 1155, 1466, 961, 1154, 1465, 960, 1153,
        1464, 959, 1542, 1346, 958, 1541, 1345, 957, 1540, 1344, 956, 1539, 
       1343, 1463, 955, 1152, 1462, 954, 1151, 1461, 953, 1538, 1342, 952, 
       1537, 1341, 951, 1639, 1297, 1325, 1296, 1326, 950, 1428, 1642, 1215, 
       1231, 1214, 1269, 1255}], 
      Line3DBox[{977, 1160, 1472, 976, 1159, 1471, 975, 1158, 1470, 974, 1550,
        1354, 973, 1549, 1353, 972, 1548, 1352, 971, 1547, 1351, 970, 1546, 
       1350, 1469, 969, 1157, 1468, 968, 1545, 1349, 967, 1544, 1348, 966, 
       1543, 1347, 965, 1628, 1262, 1304, 1261, 1305, 964, 1629, 1282, 1217, 
       1283, 1216, 1270, 1257, 1256}], 
      Line3DBox[{991, 1162, 1475, 990, 1161, 1474, 989, 1561, 1364, 988, 1560,
        1363, 987, 1559, 1362, 986, 1558, 1361, 985, 1557, 1360, 984, 1556, 
       1359, 1473, 983, 1555, 1358, 982, 1554, 1357, 981, 1553, 1356, 980, 
       1552, 1355, 979, 1420, 1551, 1306, 1308, 1307, 978, 1630, 1271, 1272, 
       1232, 1286, 1285, 1284}], 
      Line3DBox[{993, 1320, 1321, 1234, 1265, 1623, 1163, 1264, 1263, 1295, 
       1638, 1164, 995, 1476, 1165, 997, 1477, 1166, 999, 1478, 1167, 1001, 
       1479, 1168, 1003, 1480, 1370, 1569, 1005, 1481, 1169, 1007, 1482, 1170,
        1009, 1483, 1171, 1011, 1484, 1172, 1013, 1485, 1173, 1015, 1486, 
       1174, 1017, 1488, 1176, 1019}], 
      Line3DBox[{1018, 1175, 1487, 1016, 1575, 1376, 1014, 1574, 1375, 1012, 
       1573, 1374, 1010, 1572, 1373, 1008, 1571, 1372, 1006, 1570, 1371, 1004,
        1568, 1567, 1369, 1002, 1566, 1368, 1000, 1565, 1367, 998, 1564, 1366,
        996, 1563, 1365, 994, 1421, 1562, 1309, 1311, 1310, 992, 1425, 1631, 
       1273, 1233, 1289, 1288, 1287}], 
      Line3DBox[{1020, 1218, 1253, 1258, 1267, 1377, 1627, 1266, 1259, 1260, 
       1248, 1626, 1177, 1021, 1489, 1178, 1022, 1490, 1179, 1023, 1491, 1180,
        1024, 1492, 1181, 1025, 1493, 1378, 1576, 1026, 733, 1027, 1494, 1182,
        1028, 1495, 1183, 1029, 1496, 1184, 1030, 1497, 1185, 1031, 1498, 
       1186, 1032, 1499, 1187, 1033}], 
      Line3DBox[{1034, 1235, 1290, 1291, 1292, 1636, 1236, 1251, 1219, 1237, 
       1379, 1620, 1035, 1500, 1188, 1036, 1501, 1189, 1037, 1502, 1190, 1038,
        1503, 1191, 1039, 1504, 1380, 1577, 1040, 1381, 1578, 1041, 749, 1042,
        1505, 1192, 1043, 1506, 1193, 1044, 1507, 1194, 1045, 1508, 1195, 
       1046, 1509, 1196, 1047}], 
      Line3DBox[{1048, 1238, 1382, 1624, 1239, 1252, 1220, 1240, 1383, 1621, 
       1049, 1327, 1328, 1384, 1645, 1050, 1510, 1197, 1051, 1511, 1198, 1052,
        1512, 1199, 1053, 1513, 1385, 1579, 1054, 1386, 1580, 1055, 1387, 
       1581, 1056, 765, 1057, 1514, 1200, 1058, 1515, 1201, 1059, 1516, 1202, 
       1060, 1517, 1203, 1061}], 
      Line3DBox[{1063, 1274, 1275, 1632, 1062, 1276, 1221, 1241, 1222, 1643, 
       1322, 1064, 1330, 1298, 1329, 1299, 1640, 1065, 1388, 1582, 1066, 1518,
        1204, 1067, 1519, 1205, 1068, 1520, 1389, 1583, 1069, 1390, 1584, 
       1070, 1391, 1585, 1071, 1392, 1586, 1072, 780, 1073, 1521, 1206, 1074, 
       1522, 1207, 1075, 1523, 1208, 1076}], 
      Line3DBox[{1078, 1277, 1278, 1633, 1077, 1279, 1223, 1294, 1224, 1637, 
       1293, 1079, 1313, 1268, 1312, 1587, 1422, 1080, 1393, 1588, 1081, 1394,
        1589, 1082, 1524, 1209, 1083, 1525, 1395, 1590, 1084, 1396, 1591, 
       1085, 1397, 1592, 1086, 1398, 1593, 1087, 1399, 1594, 1088, 795, 1089, 
       1526, 1210, 1090, 1527, 1211, 1091}], 
      Line3DBox[{1093, 1300, 1301, 1641, 1092, 1302, 1303, 1242, 1426, 1634, 
       1280, 1094, 1315, 1316, 1314, 1595, 1423, 1095, 1400, 1596, 1096, 1401,
        1597, 1097, 1402, 1598, 1098, 1528, 1403, 1599, 1099, 1404, 1600, 
       1100, 1405, 1601, 1101, 1406, 1602, 1102, 1407, 1603, 1103, 1408, 1604,
        1104, 810, 1105, 1529, 1212, 1106}], 
      Line3DBox[{1120, 1247, 1246, 1625, 1119, 1617, 1418, 1118, 1616, 1417, 
       1117, 1615, 1416, 1116, 1614, 1415, 1115, 1613, 1414, 1114, 1612, 1413,
        1113, 1611, 1610, 1412, 1112, 1609, 1411, 1111, 1608, 1410, 1110, 
       1607, 1409, 1109, 1424, 1606, 1317, 1319, 1318, 1108, 1281, 1635, 1427,
        1243, 1225, 1107, 1419, 1605, 1244, 1245}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{399, 622, 1429, 400, 636, 428, 904, 1644, 651, 443, 890, 
       1639, 666, 458, 851, 1628, 681, 473, 1551, 854, 696, 488, 1562, 857, 
       711, 1638, 503, 837, 726, 1626, 518, 828, 1620, 741, 533, 829, 1621, 
       756, 548, 903, 830, 1643, 894, 895, 896, 563, 887, 888, 831, 1637, 862,
        863, 889, 864, 578, 1634, 881, 832, 866, 867, 868, 593, 1635, 882, 
       833, 870, 871, 872, 608}], 
      Line3DBox[{401, 623, 1430, 402, 637, 1441, 429, 1533, 652, 444, 1537, 
       667, 459, 1543, 682, 474, 1552, 697, 489, 1563, 712, 1476, 504, 727, 
       1489, 519, 742, 1500, 534, 905, 1645, 757, 549, 893, 1640, 771, 564, 
       1587, 861, 785, 579, 1595, 865, 799, 594, 1606, 869, 813, 609}], 
      Line3DBox[{403, 624, 1431, 404, 638, 1442, 430, 653, 1452, 445, 1538, 
       668, 460, 1544, 683, 475, 1553, 698, 490, 1564, 713, 1477, 505, 728, 
       1490, 520, 743, 1501, 535, 758, 1510, 550, 1582, 772, 565, 1588, 786, 
       580, 1596, 800, 595, 1607, 814, 610}], 
      Line3DBox[{405, 625, 1432, 406, 639, 1443, 431, 654, 1453, 446, 669, 
       1461, 461, 1545, 684, 476, 1554, 699, 491, 1565, 714, 1478, 506, 729, 
       1491, 521, 744, 1502, 536, 759, 1511, 551, 773, 1518, 566, 1589, 787, 
       581, 1597, 801, 596, 1608, 815, 611}], 
      Line3DBox[{407, 626, 1433, 408, 640, 1444, 432, 655, 1454, 447, 670, 
       1462, 462, 685, 1468, 477, 1555, 700, 492, 1566, 715, 1479, 507, 730, 
       1492, 522, 745, 1503, 537, 760, 1512, 552, 774, 1519, 567, 788, 1524, 
       582, 1598, 802, 597, 1609, 816, 612}], 
      Line3DBox[{409, 627, 1434, 411, 641, 1445, 433, 656, 1455, 448, 671, 
       1463, 463, 686, 1469, 478, 701, 1473, 493, 1567, 716, 1480, 508, 731, 
       1493, 523, 746, 1504, 538, 761, 1513, 553, 775, 1520, 568, 789, 1525, 
       583, 803, 1528, 598, 1610, 817, 613}], 
      Line3DBox[{413, 629, 1435, 414, 1532, 643, 435, 1535, 658, 450, 1540, 
       673, 465, 1547, 688, 480, 1557, 703, 495, 1570, 718, 1481, 510, 733, 
       525, 1578, 748, 540, 1580, 763, 555, 1584, 777, 570, 1591, 791, 585, 
       1600, 805, 600, 1612, 819, 615}], 
      Line3DBox[{415, 630, 1436, 416, 644, 1446, 436, 1536, 659, 451, 1541, 
       674, 466, 1548, 689, 481, 1558, 704, 496, 1571, 719, 1482, 511, 734, 
       1494, 526, 749, 541, 1581, 764, 556, 1585, 778, 571, 1592, 792, 586, 
       1601, 806, 601, 1613, 820, 616}], 
      Line3DBox[{417, 631, 1437, 418, 645, 1447, 437, 660, 1456, 452, 1542, 
       675, 467, 1549, 690, 482, 1559, 705, 497, 1572, 720, 1483, 512, 735, 
       1495, 527, 750, 1505, 542, 765, 557, 1586, 779, 572, 1593, 793, 587, 
       1602, 807, 602, 1614, 821, 617}], 
      Line3DBox[{419, 632, 1438, 420, 646, 1448, 438, 661, 1457, 453, 676, 
       1464, 468, 1550, 691, 483, 1560, 706, 498, 1573, 721, 1484, 513, 736, 
       1496, 528, 751, 1506, 543, 766, 1514, 558, 780, 573, 1594, 794, 588, 
       1603, 808, 603, 1615, 822, 618}], 
      Line3DBox[{421, 633, 1439, 422, 647, 1449, 439, 662, 1458, 454, 677, 
       1465, 469, 692, 1470, 484, 1561, 707, 499, 1574, 722, 1485, 514, 737, 
       1497, 529, 752, 1507, 544, 767, 1515, 559, 781, 1521, 574, 795, 589, 
       1604, 809, 604, 1616, 823, 619}], 
      Line3DBox[{423, 634, 1440, 424, 648, 1450, 440, 663, 1459, 455, 678, 
       1466, 470, 693, 1471, 485, 708, 1474, 500, 1575, 723, 1486, 515, 738, 
       1498, 530, 753, 1508, 545, 768, 1516, 560, 782, 1522, 575, 796, 1526, 
       590, 810, 605, 1617, 824, 620}], 
      Line3DBox[{425, 835, 1622, 836, 426, 649, 1451, 441, 664, 1460, 456, 
       679, 1467, 471, 694, 1472, 486, 709, 1475, 501, 724, 1487, 1488, 516, 
       739, 1499, 531, 754, 1509, 546, 769, 1517, 561, 783, 1523, 576, 797, 
       1527, 591, 811, 1529, 606, 841, 1625, 842, 843}], 
      Line3DBox[CompressedData["
1:eJwVzr9KQgEYhvEvo+aG5kBam9rKqSBtKLOjovRPixYrNShdbCmrocHdOwi6
gMALCLoAoQsIuoCgud8ZHt7ved9zOCd71k06MxFRQSMTsTIbsYdtbM1HlHRL
7ge0+L3c0C3Ia5zqunJVl5EdNHVtuaz7RZ0X+DOesKj7Rt99buvJPPaRoIQ5
+xSH9qP0XT+5I4vYxR+v2T7SZ/gBrnCJhv7H/p5+m9dwgRN9S37ZXm1VdwW3
OLbdyE/b2HbnHqTv6R/lEBPbi62sy/E3PuAJX+cj3uZr7k38A0OzJjk=
       "]], 
      Line3DBox[{614, 818, 1611, 599, 804, 1599, 584, 790, 1590, 569, 776, 
       1583, 554, 762, 1579, 539, 747, 1577, 524, 732, 1576, 509, 717, 1569, 
       1568, 494, 702, 1556, 479, 687, 1546, 464, 672, 1539, 449, 657, 1534, 
       434, 642, 1531, 412, 628, 1530, 410}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzUu3kwlu8bNi5JtiIKLSpJUVRSydZpyZoIkSVRUSRbCkmSpY3SopItVKIU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    "]],
  Axes->True,
  AxesLabel->{None, None, None},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{586.4543355426105, 367.2},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 10}, {0, 1}, {0., 2.9025754029181714`}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{-2.699536883769261, -1.2254773700052857`, 1.6311670143717307`},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6729332796879997`*^9, 3.6729335529630003`*^9, 
  3.672933752841*^9, 3.682763326479001*^9, 3.682763367189001*^9}]
}, Open  ]]
},
WindowToolbars->"EditBar",
WindowSize->{1676, 942},
WindowMargins->{{42, Automatic}, {Automatic, 60}},
FrontEndVersion->"10.3 for Microsoft Windows (64-bit) (October 10, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 228, 4, 30, "Text"],
Cell[789, 26, 5641, 175, 392, "Input"],
Cell[CellGroupData[{
Cell[6455, 205, 884, 25, 31, "Input"],
Cell[7342, 232, 15739, 273, 382, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23118, 510, 406, 11, 31, "Input"],
Cell[23527, 523, 95406, 1561, 382, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
